import hashlib
from os import urandom 

__LOGIN__HASH__SALT__ = None
def set_salt(salt):
    assert salt is not None
    global __LOGIN__HASH__SALT__
    
    if __LOGIN__HASH__SALT__ is not None:
        raise Exception("Already declared login salt!")

    __LOGIN__HASH__SALT__ = salt.encode('utf-8')

def generate_password_hash(password):
    assert password is not None
    global __LOGIN__HASH__SALT__

    if __LOGIN__HASH__SALT__ is None:
        raise Exception("Please call the set_salt() method before")

    salthash = hashlib.sha256(__LOGIN__HASH__SALT__).hexdigest()
    return hashlib.sha512(salthash.encode('utf-8') + password.encode('utf-8') + __LOGIN__HASH__SALT__).hexdigest() 

def check_password_hash(password, password_hash):
   assert password_hash is not None
   global __LOGIN__HASH__SALT__

   if __LOGIN__HASH__SALT__ is None:
       raise Exception("Please call the set_salt() method before")

   return password_hash == generate_password_hash(password) 


if __name__ == '__main__':
    password = "asfdklsjdflkj1k23123"
    set_salt("!@#!@#!@#!@")
    password_hash = generate_password_hash(password)
    assert check_password_hash(password, password_hash)



import sys
import setuptools

if sys.version_info < (3,):
    print("Unfortunately, your python version is not supported!\n"
          + "Please upgrade at least to Python 3!")
    sys.exit(1)

with open("README.rst", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="login",
    python_requires='>=3',
    version="0.0.6",
    author="ksg97031",
    author_email="ksg97031@gmail.com",
    description="Module for common login service",
    long_description=long_description,
    long_description_content_type="text/x-rst",
    url="https://github.com/ksg97031/login",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)
